@@ -12,11 +12,17 @@ __all__ = (
     "PyQueryStrictSearch",
 )
 
+_pseudo_with_values = [
+    "attr",
+    "has_class",
+]
+
 _attr_shortcut_mappings = {
     "val": "value",
     "src": "src",
     "href": "href",
     "name": "name",
+    "class": "class",
     "content": "content",
 }
 
@@ -24,7 +30,7 @@ _attr_shortcut_mappings = {
 class PyQuerySearch(QuerySearch):
     def __init__(
         self,
-        query: Optional[str],
+        query: str,
         remove_query: Optional[str] = None,
         **kwargs,
     ):
@@ -35,11 +41,13 @@ class PyQuerySearch(QuerySearch):
 
         self._first: bool = True
         self._attr: Optional[str] = None
+        self._has_class: Optional[str] = None
         self._text: bool = False
         self._ntext: bool = False
         self._html: bool = False
         self._outer_html: bool = False
         self._items: bool = False
+        self._iter: bool = False
 
         if self._query and "::" in self._query:
             self._initialize_custom_pseudo_keys()
@@ -50,8 +58,10 @@ class PyQuerySearch(QuerySearch):
         query: Optional[str],
     ) -> Any:
 
+        if self._iter:
+            return self._iter_parse(pq, query=query)
         if self._items:
-            return [i for i in self._iter_parse(pq, query=query)]
+            return list(self._iter_parse(pq, query=query))
         else:
             pq = self._parse_pq(pq, query=query, first=self._first)
 
@@ -98,6 +108,9 @@ class PyQuerySearch(QuerySearch):
             return pq.html() or None
         elif self._outer_html:
             return pq.outer_html() or None
+        elif self._has_class:
+            # Returns bool
+            return pq.has_class(self._has_class)
         elif self._attr:
             return pq.attr(self._attr) or None
 
@@ -129,27 +142,33 @@ class PyQuerySearch(QuerySearch):
         self._process_pseudo_key(pseudo_key)
 
     def _process_pseudo_key_extension(self, pseudo_key: str) -> str:
-        pseudo_key, extension = pseudo.get_extension_value(pseudo_key, ["attr"])
+        pseudo_key, extension = pseudo.get_extension_value(
+            pseudo_key=pseudo_key,
+            pseudo_keys_with_separator_value=["attr", "has_class"],
+        )
 
         if not extension:
             return pseudo_key
 
-        if extension == "items":
+        if extension == "iter":
+            self._iter = True
+        elif extension == "items":
             self._items = True
         elif extension == "all":
             self._first = False
         else:
             raise ValueError(
                 "Pseudo key extension {} is not supported. Currently supported "
-                "are -items and -all".format(extension)
+                "are -items, -iter and -all".format(extension)
             )
 
         return pseudo_key
 
     def _process_pseudo_key(self, pseudo_key: str) -> None:
         if pseudo_key.startswith("attr"):
-            attr_value = pseudo_key.split("(")[-1].strip(")")
-            self._attr = attr_value
+            self._attr = pseudo.get_value(pseudo_key)
+        elif pseudo_key.startswith("has_class"):
+            self._has_class = pseudo.get_value(pseudo_key)
         elif pseudo_key in _attr_shortcut_mappings:
             self._attr = _attr_shortcut_mappings[pseudo_key]
         elif pseudo_key == "text":
@@ -162,12 +181,13 @@ class PyQuerySearch(QuerySearch):
             self._outer_html = True
         elif pseudo_key == "items":
             self._items = True
+        elif pseudo_key == "iter":
+            self._iter = True
         else:
             raise ValueError(
                 "Pseudo key '{}' is not supported. Currently supported are: text,"
-                "ntext,html,ohtml,items, attr(<value>),{}".format(
-                    pseudo_key, ",".join(_attr_shortcut_mappings.keys())
-                )
+                "ntext,html,ohtml,items,iter,has_class(<value>),attr(<value>),"
+                "{}".format(pseudo_key, ",".join(_attr_shortcut_mappings.keys()))
             )
 
 
