@@ -1,4 +1,4 @@
-from easydata.contrib.scrapy import ItemModelSpider
+from easydata.contrib.scrapy import EDSpider
 from tests.factory.scrapy import (
     EXPECTED_PRODUCT_ITEM_RESULT,
     EXPECTED_PRODUCT_ITEM_RESULT_SCRAPY_ITEM,
@@ -8,20 +8,20 @@ from tests.factory.scrapy import (
 )
 
 
-class DemoSpider(ItemModelSpider):
+class DemoSpider(EDSpider):
     name = "demo"
 
 
-class DemoItemModelSpider(DemoSpider):
+class DemoEDSpider(DemoSpider):
     item_model_cls = ProductItemModel
 
 
-class DemoInnerClassItemModelSpider(DemoSpider):
+class DemoInnerClassEDSpider(DemoSpider):
     class ItemModel(ProductItemModel):
         pass
 
 
-class DemoStackedItemModelSpider(DemoSpider):
+class DemoStackedEDSpider(DemoSpider):
     item_model_obj = PRODUCT_ITEM_STACKED_MODEL
 
 
@@ -32,18 +32,18 @@ def get_spider_result(spider):
 
 
 def test_item_model_spider():
-    demo_spider = DemoItemModelSpider()
+    demo_spider = DemoEDSpider()
 
     assert get_spider_result(demo_spider) == EXPECTED_PRODUCT_ITEM_RESULT_SCRAPY_ITEM
 
 
 def test_item_model_spider_with_inner_class():
-    demo_spider = DemoInnerClassItemModelSpider()
+    demo_spider = DemoInnerClassEDSpider()
 
     assert get_spider_result(demo_spider) == EXPECTED_PRODUCT_ITEM_RESULT_SCRAPY_ITEM
 
 
 def test_stacked_item_model_spider():
-    demo_spider = DemoStackedItemModelSpider()
+    demo_spider = DemoStackedEDSpider()
 
     assert get_spider_result(demo_spider) == EXPECTED_PRODUCT_ITEM_RESULT
